@@ -15,7 +15,7 @@
 # pylint: disable=protected-access
 import unittest
 
-from opentelemetry.exporter.otlp.proto.common.metrics_encoder import (
+from snowflake.telemetry._internal.opentelemetry.exporter.otlp.proto.common.metrics_encoder import (
     encode_metrics,
 )
 from opentelemetry.proto.collector.metrics.v1.metrics_service_pb2 import (
@@ -33,10 +33,8 @@ from opentelemetry.proto.resource.v1.resource_pb2 import (
 from opentelemetry.sdk.metrics.export import AggregationTemporality, Buckets
 from opentelemetry.sdk.metrics.export import (
     ExponentialHistogram as ExponentialHistogramType,
-)
-from opentelemetry.sdk.metrics.export import ExponentialHistogramDataPoint
-from opentelemetry.sdk.metrics.export import Histogram as HistogramType
-from opentelemetry.sdk.metrics.export import (
+    Histogram as HistogramType,
+    ExponentialHistogramDataPoint,
     HistogramDataPoint,
     Metric,
     MetricsData,
@@ -161,8 +159,8 @@ class TestOTLPMetricsEncoder(unittest.TestCase):
                 )
             ]
         )
-        actual = encode_metrics(metrics_data)
-        self.assertEqual(expected, actual)
+        actual = encode_metrics(metrics_data).SerializeToString()
+        self.assertEqual(expected.SerializeToString(), actual)
         self.metric_writer.clear()
         self.exporter.export(metrics_data)
         protos = self.metric_writer.get_finished_protos()
@@ -247,8 +245,8 @@ class TestOTLPMetricsEncoder(unittest.TestCase):
                 )
             ]
         )
-        actual = encode_metrics(metrics_data)
-        self.assertEqual(expected, actual)
+        actual = encode_metrics(metrics_data).SerializeToString()
+        self.assertEqual(expected.SerializeToString(), actual)
         self.metric_writer.clear()
         self.exporter.export(metrics_data)
         protos = self.metric_writer.get_finished_protos()
@@ -330,8 +328,8 @@ class TestOTLPMetricsEncoder(unittest.TestCase):
                 )
             ]
         )
-        actual = encode_metrics(metrics_data)
-        self.assertEqual(expected, actual)
+        actual = encode_metrics(metrics_data).SerializeToString()
+        self.assertEqual(expected.SerializeToString(), actual)
         self.metric_writer.clear()
         self.exporter.export(metrics_data)
         protos = self.metric_writer.get_finished_protos()
@@ -413,8 +411,8 @@ class TestOTLPMetricsEncoder(unittest.TestCase):
                 )
             ]
         )
-        actual = encode_metrics(metrics_data)
-        self.assertEqual(expected, actual)
+        actual = encode_metrics(metrics_data).SerializeToString()
+        self.assertEqual(expected.SerializeToString(), actual)
         self.metric_writer.clear()
         self.exporter.export(metrics_data)
         protos = self.metric_writer.get_finished_protos()
@@ -504,8 +502,8 @@ class TestOTLPMetricsEncoder(unittest.TestCase):
                 )
             ]
         )
-        actual = encode_metrics(metrics_data)
-        self.assertEqual(expected, actual)
+        actual = encode_metrics(metrics_data).SerializeToString()
+        self.assertEqual(expected.SerializeToString(), actual)
         self.metric_writer.clear()
         self.exporter.export(metrics_data)
         protos = self.metric_writer.get_finished_protos()
@@ -732,8 +730,8 @@ class TestOTLPMetricsEncoder(unittest.TestCase):
                 )
             ]
         )
-        actual = encode_metrics(metrics_data)
-        self.assertEqual(expected, actual)
+        actual = encode_metrics(metrics_data).SerializeToString()
+        self.assertEqual(expected.SerializeToString(), actual)
         self.metric_writer.clear()
         self.exporter.export(metrics_data)
         protos = self.metric_writer.get_finished_protos()
@@ -858,8 +856,8 @@ class TestOTLPMetricsEncoder(unittest.TestCase):
             ]
         )
         # pylint: disable=protected-access
-        actual = encode_metrics(metrics_data)
-        self.assertEqual(expected, actual)
+        actual = encode_metrics(metrics_data).SerializeToString()
+        self.assertEqual(expected.SerializeToString(), actual)
         self.metric_writer.clear()
         self.exporter.export(metrics_data)
         protos = self.metric_writer.get_finished_protos()
